pub struct StreamFuture<T> { /* private fields */ }Expand description
A future that waits for a stream value.
This is created by Stream::next.
Implementations
Sourceimpl<T: Clone + Send + 'static> StreamFuture<T>
impl<T: Clone + Send + 'static> StreamFuture<T>
Sourcepub fn get_source(&self) -> &Stream<T>
pub fn get_source(&self) -> &Stream<T>
Obtains the source stream.
Sourcepub fn reload(&self)
pub fn reload(&self)
Reuses a finished future so it can wait for another value.
Normally calling poll on a future after it returned Poll::Ready will panic.
This method will restart this future so it can be polled again for another value.
This allows awaiting for multiple values without having to create and allocate multiple
future objects.
Calling this on a pending (or ready but unread) future will have no effect.